==> xfwm4-3.99.4.tar.bz2: xfwm4-3.99.4/src/main.h <==
/*
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; You may only use version 2 of the License,
        you have no option to use any other version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2003 Olivier Fourdan
 
 */

#ifndef INC_MAIN_H
#define INC_MAIN_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <signal.h>
#include <unistd.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xmd.h>
#include <X11/cursorfont.h>
#include <X11/extensions/shape.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <libxfcegui4/libxfcegui4.h>
#include "client.h"
#include "misc.h"
#include "hints.h"
#include "keyboard.h"
#include "mypixmap.h"
#include "parserc.h"

/*
 *
 * Global variables
 *
 */

extern char *progname;
extern Display *dpy;
extern Window root, gnome_win, sidewalk[2];
extern Screen *xscreen;
extern int screen;
extern int depth;
extern int workspace;
extern gboolean use_xinerama;
extern int xinerama_heads;
extern Colormap cmap;
extern int gnome_margins[4];
extern int margins[4];
extern int quit, reload;
extern int shape, shape_event;
extern Cursor resize_cursor[7], move_cursor, busy_cursor, root_cursor;

#endif /* INC_MAIN_H */

==> xfwm4-4.0.5.tar.bz2: xfwm4-4.0.5/src/main.h <==
/*
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; You may only use version 2 of the License,
        you have no option to use any other version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2003 Olivier Fourdan
 
 */

#ifndef INC_MAIN_H
#define INC_MAIN_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <sys/stat.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <signal.h>
#include <unistd.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xmd.h>
#include <X11/cursorfont.h>
#include <X11/extensions/shape.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <libxfcegui4/libxfcegui4.h>
#include "client.h"
#include "misc.h"
#include "hints.h"
#include "keyboard.h"
#include "mypixmap.h"
#include "parserc.h"

/*
 *
 * Global variables
 *
 */

extern char *progname;
extern Time last_timestamp;
extern Display *dpy;
extern Window root, gnome_win, systray, sidewalk[2];
extern Screen *xscreen;
extern int screen;
extern int depth;
extern int workspace;
extern gboolean use_xinerama;
extern int xinerama_heads;
extern Colormap cmap;
extern int gnome_margins[4];
extern int margins[4];
extern int quit, reload;
extern int shape, shape_event;
extern Cursor resize_cursor[7], move_cursor, busy_cursor, root_cursor;

#endif /* INC_MAIN_H */
